@@ -36,6 +36,7 @@ class SAFRSRequest(Request):
     filter = ""  # filter is the custom filter, used as an argument by _s_filter
     includes = []
     secure = True
+    parsed_qs = {}
 
     def __init__(self, *args, **kwargs):
         """
@@ -97,10 +98,12 @@ class SAFRSRequest(Request):
             - filter[]
             - fields[]
         """
+
         self.page_limit = self.args.get("page[limit]", get_config("MAX_PAGE_LIMIT"), type=int)
         self.page_offset = self.args.get("page[offset]", 0, type=int)
         self.filters = {}
         self.fields = {}
+
         # Parse the jsonapi filter[] and fields[] args
         for arg, val in self.args.items():
             if arg == "filter":
@@ -118,4 +121,4 @@ class SAFRSRequest(Request):
                 self.fields[field_type] = val.split(",")
 
             if arg == "include":
-                self.includes = val.split(',')
\ No newline at end of file
+                self.includes = val.split(",")
