@@ -1,8 +1,7 @@
-"""
-Functions for api documentation: these decorators generate the swagger schemas
-
-This should evolve to a more declarative version in the future with templates
-"""
+#
+# # Functions for api documentation: these decorators generate the swagger schemas
+# This should evolve to a more declarative version in the future with templates
+#
 import inspect
 import datetime
 import json
@@ -31,6 +30,10 @@ debug_responses = {
     HTTPStatus.INTERNAL_SERVER_ERROR.value: {"description": HTTPStatus.INTERNAL_SERVER_ERROR.description},
 }
 
+# List to generate the swagger references / definitions unique name
+Schema._reference_count = []
+Schema._references = {}
+
 
 # pylint: disable=redefined-builtin,line-too-long,protected-access,logging-format-interpolation
 def parse_object_doc(object):
@@ -142,11 +145,6 @@ def SchemaClassFactory(name, properties):
     return new_schema_cls
 
 
-# List to generate the swagger references / definitions unique name
-Schema._reference_count = []
-Schema._references = {}
-
-
 def encode_schema(obj):
     """
         None aka "null" is invalid in swagger schema definition
@@ -633,7 +631,12 @@ def apply_fstring(swagger_obj, vars, k=None):
         Format the f-strings in the swagger object
     """
     if isinstance(swagger_obj, str):
-        return swagger_obj.format(**vars)
+        result = swagger_obj
+        try:
+            result = swagger_obj.format(**vars)
+        except Exception as exc:
+            safrs.log.error("Failed to format ({})".format(exc))
+        return result
     elif isinstance(swagger_obj, list):
         for i in swagger_obj:
             apply_fstring(i, vars)
